# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/) and this project adheres to [Semantic Versioning](http://semver.org/spec/v2.0.0.html).

## [Unreleased]
_Nothing yet_

## [0.1.0] - 2023-03-02
### Added
- Initial Python API, with `is_gellermann_series`, `generate_gellermann_series`, `generate_all_gellermann_series`, and `generate_gellermann_series_table`
- Basic GUI, with PyInstaller-generated standalone executables for Linux, macOS, and Windows

[0.1.0]: https://github.com/YannickJadoul/PyGellermann/compare/v0.1.0...HEAD
[Unreleased]: https://github.com/YannickJadoul/PyGellermann/compare/e013a30...v0.1.0
